@@ -31,7 +31,7 @@
         (?f . ("«" "»")) ;; french quotes (or, more precisely, Russian quotes)
         (?F . ("‹" "›")) ;; single variation of the above
         (?h . ("#" "#")) ;; hash
-        (?s . ("`" "'")) ;; (emacs) Symbol 
+        (?s . ("`" "'")) ;; (emacs) Symbol
         (?m . ("\\(" "\\)")) ;; Math
         (?M . ("\\[" "\\]")) ;; display Math
         (?o . ("⟦" "⟧")) ;; oxford brackets
@@ -56,7 +56,8 @@
     (if choice (cdr choice) (list s s))))
 
 (defun boon-select-from-region (select-fun)
-  "Return a region list with a single item: the region selected after calling SELECT-FUN (interactively)."
+  "Select the region selected after calling SELECT-FUN (interactively).
+A region list with a single item is returned."
   (lambda ()
     (save-mark-and-excursion
      (call-interactively select-fun)
@@ -151,6 +152,8 @@ This item is either the symbol at point, or, if this fails, the sexp at point."
 (declare-function LaTeX-find-matching-begin "latex.el")
 (declare-function LaTeX-find-matching-end   "latex.el")
 (defun boon-select-LaTeX-env-command ()
+  "Selector of the enclosing environment name.
+There are two occurrences: one at begin and one at end."
   (interactive)
   (lambda ()
     (list
@@ -193,7 +196,9 @@ This item is either the symbol at point, or, if this fails, the sexp at point."
     (boon-regs-from-bounds (cons (point) (nth (1- count) (cons (mark t) mark-ring))))))
     
 (defun boon-select-block ()
-  "Select the lines contiguous with the current line and have same indentation or more."
+  "Select a block.
+A block is defined as the lines contiguous with the current line and
+have same indentation or more."
   (interactive)
   (lambda ()
     (boon-regs-from-bounds
@@ -245,7 +250,7 @@ then ask for the string interactively instead."
                                result))))
         result))))
 
-(defun boon-select-word-occurences (what-fun where)
+(defun boon-select-symbol-occurences (what-fun where)
   "Return the occurences of WHAT-FUN as sub-regions of WHERE."
   (interactive (list (boon-spec-string-lazy "occurences of what?") (boon-spec-selector "where?")))
   (lambda ()
@@ -256,9 +261,9 @@ then ask for the string interactively instead."
           (goto-char (boon-reg-begin reg))
           (while (search-forward-regexp
                   (rx-to-string
-                   `(seq word-start
+                   `(seq symbol-start
                          (literal ,what)
-                         word-end)
+                         symbol-end)
                    t)
                   (boon-reg-end reg) t)
             (setq result (cons (boon-mk-reg (match-beginning 0)
@@ -341,7 +346,7 @@ cursor), you get a region for each cursor."
   "Non nil if the last selection was made by a move, nil otherwise.
 When killing, if a selection is made by a move, it makes sense to
 aggregate the region in the killring, but not so if it was made
-by a 'true' selector.")
+by a \"true\" selector.")
 
 (defun boon-spec-selector (msg)
   "Specify a region selector concisely using the keyboard.
