@@ -156,7 +156,9 @@ Return nil if no changes are made."
 
 ;;;###autoload
 (defun boon-toggle-case ()
-  "Toggle the case of the character at point, or cycle the case of the region if it is active."
+  "Toggle the case.
+Cycle the case of the region if it is active.  If not toggle the
+case of the character at point."
   (interactive)
   (if (use-region-p)
       (call-interactively 'boon-toggle-region-case)
@@ -287,13 +289,19 @@ If there is more than one, use mc/create-fake-cursor-at-point."
 
 ;;;###autoload
 (defun boon-exchange (regs)
+  "Exchange the REGS contents with the last kill.
+Do so at the position of the last kill, according to `mark-ring'."
   (interactive (list (boon-spec-select-top "exchange")))
-  (let ((last-command nil)) ;; we never want to append to the last kill here
-    (boon-take-region regs)) 
-  (insert-for-yank (nth 1 kill-ring))
-  (save-excursion
-    (goto-char (nth 0 mark-ring))
-    (insert-for-yank (nth 0 kill-ring))))
+  (let ((regp (use-region-p)))
+    (let ((last-command nil)) ;; we never want to append to the last kill here
+      (boon-take-region regs))
+    (when regp
+      ;; if the region is active then we pushed another mark which must be ignored.
+      (pop mark-ring))
+    (insert-for-yank (nth 1 kill-ring))
+    (save-excursion
+      (goto-char (nth 0 mark-ring))
+      (insert-for-yank (nth 0 kill-ring)))))
 
 ;;;###autoload
 (defun boon-take-region (regs)
@@ -334,7 +342,7 @@ If there is more than one, use mc/create-fake-cursor-at-point."
 
 ;;;###autoload
 (defun boon-substitute-region (reg-sel &optional changes)
-  "Kill the regions REGS, and switch to insertion mode or replay CHANGES."
+  "Kill the regions REG-SEL, and switch to insertion mode or replay CHANGES."
   (interactive (list (boon-spec-select-top "replace")))
   (boon-interactive-insert reg-sel)
   
@@ -366,7 +374,8 @@ Replace the region if it is active."
 
 ;;;###autoload
 (defun boon-quote-character (char)
-  "Execute the command which were bound to the character CHAR if boon was not enabled."
+  "Execute the command which would bound to the character CHAR.
+\(If boon was not enabled.\)"
   (interactive (list (read-char))) ;; use read-char so that multiple-cursors advice kicks in.
   (let* ((keymap (make-composed-keymap
                   (let ((boon-mode-map-alist nil)) (current-active-maps))))
@@ -400,6 +409,10 @@ Replace the region if it is active."
    ((use-region-p)
     (boon-deactivate-mark)
     (message "Deactivated region (use ' to reactivate)"))
+   ((derived-mode-p 'completion-list-mode)
+    (delete-completion-window))   
+   ((> (minibuffer-depth) 0)
+    (abort-recursive-edit))   
    ((bound-and-true-p multiple-cursors-mode)
     (message "Exitted from multiple cursors")
     (multiple-cursors-mode 0))
@@ -410,12 +423,13 @@ Replace the region if it is active."
     (keyboard-quit))))
 
 (defun boon-god-control-swap (event)
-  "Swap the control 'bit' in EVENT, unless C-c <event> is a prefix reserved for modes."
+  "Swap the control \"bit\" in EVENT.
+Act as identity function if C-c <event> is a prefix reserved for modes."
   (interactive (list (read-key)))
   (cond
    ((memq event '(9 13 ?{ ?} ?\[ ?\] ?$ ?& ?= ?< ?> ?: ?\; ?/ ?? ?. ?, ?' ?` ?\" )) event)
    ((<= event 27) (+ 96 event))
-   ((not (eq 0 (logand (lsh 1 26) event))) (logxor (lsh 1 26) event))
+   ((not (eq 0 (logand (ash 1 26) event))) (logxor (ash 1 26) event))
    (t (list 'control event))))
 
 ;;;###autoload
@@ -423,7 +437,8 @@ Replace the region if it is active."
   "Input a key sequence, prepending C- to each key (unless such
 key is already reserved for minor mode, see
 `boon-god-control-swap'), and run the command bound to that
-sequence."
+sequence.  The universal argument ARG is forwarded to the
+inputted command."
   (interactive "P")
   (let ((keys '((control c)))
         (binding (key-binding (kbd "C-c")))
